/*******************************************************************************
 * Copyright (c) 1991, 2021 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: ROMClassManagerConstants
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class ROMClassManagerConstants {

	// VM Constants

	public static final long SIZEOF;
	public static final long LOCATE_ROMCLASS_RETURN_DO_MARK_CPEI_STALE;
	public static final long LOCATE_ROMCLASS_RETURN_DO_TRY_WAIT;
	public static final long LOCATE_ROMCLASS_RETURN_FOUND;
	public static final long LOCATE_ROMCLASS_RETURN_FOUND_SHADOW;
	public static final long LOCATE_ROMCLASS_RETURN_MARKED_ITEM_STALE;
	public static final long LOCATE_ROMCLASS_RETURN_NOTFOUND;
	public static final long ROMCLASSMANAGERIMPL_H_INCLUDED;
	public static final long ROMCLASSMANAGERIMPL_H_INCLUDED_DEFINED;
	public static final long ROMCLASS_RESOURCE_MANAGER_HPP_INCLUDED;
	public static final long ROMCLASS_RESOURCE_MANAGER_HPP_INCLUDED_DEFINED;
	public static final long SCOPEMANAGERIMPL_H_INCLUDED;
	public static final long SCOPEMANAGERIMPL_H_INCLUDED_DEFINED;
	public static final long SCOPEMANAGER_HPP_INCLUDED;
	public static final long SCOPEMANAGER_HPP_INCLUDED_DEFINED;
	public static final long SHAREDCACHE_HPP_INCLUDED;
	public static final long SHAREDCACHE_HPP_INCLUDED_DEFINED;
	public static final long TIMESTAMPMANAGERIMPL_HPP_INCLUDED;
	public static final long TIMESTAMPMANAGERIMPL_HPP_INCLUDED_DEFINED;
	public static final long TIMESTAMPMANAGER_HPP_INCLUDED;
	public static final long TIMESTAMPMANAGER_HPP_INCLUDED_DEFINED;


	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		LOCATE_ROMCLASS_RETURN_DO_MARK_CPEI_STALE = 0;
		LOCATE_ROMCLASS_RETURN_DO_TRY_WAIT = 0;
		LOCATE_ROMCLASS_RETURN_FOUND = 0;
		LOCATE_ROMCLASS_RETURN_FOUND_SHADOW = 0;
		LOCATE_ROMCLASS_RETURN_MARKED_ITEM_STALE = 0;
		LOCATE_ROMCLASS_RETURN_NOTFOUND = 0;
		ROMCLASSMANAGERIMPL_H_INCLUDED = 0;
		ROMCLASSMANAGERIMPL_H_INCLUDED_DEFINED = 0;
		ROMCLASS_RESOURCE_MANAGER_HPP_INCLUDED = 0;
		ROMCLASS_RESOURCE_MANAGER_HPP_INCLUDED_DEFINED = 0;
		SCOPEMANAGERIMPL_H_INCLUDED = 0;
		SCOPEMANAGERIMPL_H_INCLUDED_DEFINED = 0;
		SCOPEMANAGER_HPP_INCLUDED = 0;
		SCOPEMANAGER_HPP_INCLUDED_DEFINED = 0;
		SHAREDCACHE_HPP_INCLUDED = 0;
		SHAREDCACHE_HPP_INCLUDED_DEFINED = 0;
		TIMESTAMPMANAGERIMPL_HPP_INCLUDED = 0;
		TIMESTAMPMANAGERIMPL_HPP_INCLUDED_DEFINED = 0;
		TIMESTAMPMANAGER_HPP_INCLUDED = 0;
		TIMESTAMPMANAGER_HPP_INCLUDED_DEFINED = 0;
	}

}
