/*******************************************************************************
 * Copyright (c) 1991, 2021 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: __sFILE
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class __sFILE {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __bfOffset_;
	public static final int __blksizeOffset_;
	public static final int __closeOffset_;
	public static final int __cookieOffset_;
	public static final int __extraOffset_;
	public static final int __fileOffset_;
	public static final int __flagsOffset_;
	public static final int __lbOffset_;
	public static final int __lbfsizeOffset_;
	public static final int __nbufOffset_;
	public static final int __offsetOffset_;
	public static final int __pOffset_;
	public static final int __rOffset_;
	public static final int __readOffset_;
	public static final int __seekOffset_;
	public static final int __ubOffset_;
	public static final int __ubufOffset_;
	public static final int __urOffset_;
	public static final int __wOffset_;
	public static final int __writeOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__bfOffset_ = 0;
		__blksizeOffset_ = 0;
		__closeOffset_ = 0;
		__cookieOffset_ = 0;
		__extraOffset_ = 0;
		__fileOffset_ = 0;
		__flagsOffset_ = 0;
		__lbOffset_ = 0;
		__lbfsizeOffset_ = 0;
		__nbufOffset_ = 0;
		__offsetOffset_ = 0;
		__pOffset_ = 0;
		__rOffset_ = 0;
		__readOffset_ = 0;
		__seekOffset_ = 0;
		__ubOffset_ = 0;
		__ubufOffset_ = 0;
		__urOffset_ = 0;
		__wOffset_ = 0;
		__writeOffset_ = 0;
	}

}
