/*******************************************************************************
 * Copyright (c) 1991, 2021 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: stat
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class stat {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _st_atimespecOffset_;
	public static final int _st_birthtimespecOffset_;
	public static final int _st_blksizeOffset_;
	public static final int _st_blocksOffset_;
	public static final int _st_ctimespecOffset_;
	public static final int _st_devOffset_;
	public static final int _st_flagsOffset_;
	public static final int _st_genOffset_;
	public static final int _st_gidOffset_;
	public static final int _st_inoOffset_;
	public static final int _st_lspareOffset_;
	public static final int _st_modeOffset_;
	public static final int _st_mtimespecOffset_;
	public static final int _st_nlinkOffset_;
	public static final int _st_qspareOffset_;
	public static final int _st_rdevOffset_;
	public static final int _st_sizeOffset_;
	public static final int _st_uidOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_st_atimespecOffset_ = 0;
		_st_birthtimespecOffset_ = 0;
		_st_blksizeOffset_ = 0;
		_st_blocksOffset_ = 0;
		_st_ctimespecOffset_ = 0;
		_st_devOffset_ = 0;
		_st_flagsOffset_ = 0;
		_st_genOffset_ = 0;
		_st_gidOffset_ = 0;
		_st_inoOffset_ = 0;
		_st_lspareOffset_ = 0;
		_st_modeOffset_ = 0;
		_st_mtimespecOffset_ = 0;
		_st_nlinkOffset_ = 0;
		_st_qspareOffset_ = 0;
		_st_rdevOffset_ = 0;
		_st_sizeOffset_ = 0;
		_st_uidOffset_ = 0;
	}

}
